@@ -1,16 +1,13 @@
 from itertools import chain, repeat
 
-try:
-    from invoke.vendor.six import b, StringIO
-except ImportError:
-    from six import b, StringIO
+from io import StringIO
 
 import errno
 from os.path import join
 import socket
 import time
 
-from mock import patch, Mock, call, ANY
+from unittest.mock import patch, Mock, call, ANY
 from paramiko.client import SSHClient, AutoAddPolicy
 from paramiko import SSHConfig
 import pytest  # for mark, internal raises
@@ -506,14 +503,16 @@ class Connection_:
 
         class inline_ssh_env:
             def defaults_to_config_value(self):
-                assert Connection("host").inline_ssh_env is False
-                config = Config({"inline_ssh_env": True})
-                assert Connection("host", config=config).inline_ssh_env is True
+                assert Connection("host").inline_ssh_env is True
+                config = Config({"inline_ssh_env": False})
+                assert (
+                    Connection("host", config=config).inline_ssh_env is False
+                )
 
             def may_be_given(self):
-                assert Connection("host").inline_ssh_env is False
-                cxn = Connection("host", inline_ssh_env=True)
-                assert cxn.inline_ssh_env is True
+                assert Connection("host").inline_ssh_env is True
+                cxn = Connection("host", inline_ssh_env=False)
+                assert cxn.inline_ssh_env is False
 
     class from_v1:
         def setup(self):
@@ -546,11 +545,11 @@ class Connection_:
                 cxn = Connection.from_v1(
                     self.env,
                     connect_kwargs={"foo": "bar"},
-                    inline_ssh_env=True,
+                    inline_ssh_env=False,
                     connect_timeout=15,
                 )
                 assert cxn.connect_kwargs["foo"] == "bar"
-                assert cxn.inline_ssh_env is True
+                assert cxn.inline_ssh_env is False
                 assert cxn.connect_timeout == 15
 
             def conflicting_kwargs_win_over_v1_env_values(self):
@@ -962,6 +961,24 @@ class Connection_:
             c.close()
             client.close.assert_called_with()
 
+        def calls_SFTPClient_close(self, client):
+            "calls paramiko.SFTPClient.close()"
+            c = Connection("host")
+            c.open()
+            sftp_client = c.sftp()
+            assert c._sftp is not None
+            c.close()
+            assert c._sftp is None
+            sftp_client.close.assert_called_with()
+
+        def calls_SFTPClient_close_not_called_if_not_open(self, client):
+            "calls paramiko.SFTPClient.close()"
+            c = Connection("host")
+            c.open()
+            assert c._sftp is None
+            c.close()
+            assert c._sftp is None
+
         @patch("fabric.connection.AgentRequestHandler")
         def calls_agent_handler_close_if_enabled(self, Handler, client):
             c = Connection("host", forward_agent=True)
@@ -1013,9 +1030,9 @@ class Connection_:
         @patch(remote_path)
         def passes_inline_env_to_Remote(self, Remote, client):
             Connection("host").run("command")
-            assert Remote.call_args[1]["inline_env"] is False
-            Connection("host", inline_ssh_env=True).run("command")
             assert Remote.call_args[1]["inline_env"] is True
+            Connection("host", inline_ssh_env=False).run("command")
+            assert Remote.call_args[1]["inline_env"] is False
 
         @patch(remote_path)
         def calls_Remote_run_with_command_and_kwargs_and_returns_its_result(
@@ -1029,7 +1046,7 @@ class Connection_:
             # .assert_called_with()) stopped working, apparently triggered by
             # our code...somehow...after commit (roughly) 80906c7.
             # And yet, .call_args_list and its brethren work fine. Wha?
-            Remote.assert_any_call(context=c, inline_env=False)
+            Remote.assert_any_call(context=c, inline_env=True)
             remote.run.assert_has_calls(
                 [call("command"), call("command", warn=True, hide="stderr")]
             )
@@ -1120,9 +1137,9 @@ class Connection_:
         @patch(remote_path)
         def passes_inline_env_to_Remote(self, Remote, client):
             Connection("host").sudo("command")
-            assert Remote.call_args[1]["inline_env"] is False
-            Connection("host", inline_ssh_env=True).sudo("command")
             assert Remote.call_args[1]["inline_env"] is True
+            Connection("host", inline_ssh_env=False).sudo("command")
+            assert Remote.call_args[1]["inline_env"] is False
 
         @patch(remote_path)
         def basic_invocation(self, Remote, client):
@@ -1136,7 +1153,7 @@ class Connection_:
             # Remote.return_value is two different Mocks now, despite Remote's
             # own Mock having the same ID here and in code under test. WTF!!)
             expected = [
-                call(context=cxn, inline_env=False),
+                call(context=cxn, inline_env=True),
                 call().run(cmd, watchers=ANY),
             ]
             assert Remote.mock_calls == expected
@@ -1213,7 +1230,7 @@ class Connection_:
             listener_sock = Mock(name="listener_sock")
             if listener_exception:
                 listener_sock.bind.side_effect = listener_exception
-            data = b("Some data")
+            data = "Some data".encode()
             tunnel_sock = Mock(name="tunnel_sock", recv=lambda n: data)
             local_addr = Mock()
             transport = client.get_transport.return_value
@@ -1224,6 +1241,7 @@ class Connection_:
             # fire once & raise EAGAIN after)
             listener_sock.accept.side_effect = chain(
                 [(tunnel_sock, local_addr)],
+                # TODO: should this become BlockingIOError too?
                 repeat(socket.error(errno.EAGAIN, "nothing yet")),
             )
             obj = tunnel_sock if tunnel_exception is None else tunnel_exception
