@@ -1,9 +1,6 @@
-try:
-    from invoke.vendor.six import StringIO
-except ImportError:
-    from six import StringIO
+from io import StringIO
 
-from mock import Mock, patch
+from unittest.mock import Mock, patch
 from pytest import skip  # noqa
 
 from invoke import pty_size, Result
